ToolInfo class

Information about a tool extracted from annotations.

Constructors

ToolInfo({required String name, required String description, required List<ParameterInfo> parameters})

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
parameters List<ParameterInfo>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonSchema() Map<String, dynamic>
Generate JSON-Schema for tool parameters.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited