path property

String path
final

The relative path of the file under the root of package.

The path is relative and contains no parent references .., guaranteeing that it is under package.

The path segment separator is / on all platforms.

Implementation

final String path;