serialize method
Serializes this AssetId to an Object that can be sent across isolates.
See AssetId.deserialize.
Implementation
Object serialize() => [package, path];
Serializes this AssetId to an Object that can be sent across isolates.
See AssetId.deserialize.
Object serialize() => [package, path];