canRead abstract method
Indicates whether id can be read by this build step.
That means the file exists, and it is visible to this build step.
Files that are generated by builders that run after the current builder
are hidden, even if they physically exist on disk due to an earlier build.
For such files, canRead returns false and the read methods will
throw AssetNotFoundException.
Implementation
@override
Future<bool> canRead(AssetId id);