findAssets abstract method
Returns all readable assets matching glob under the current package.
This includes generated assets output by builders that run before the current builder, but not generated assets that will be output by builders that will run after the current builder.
Implementation
@override
Stream<AssetId> findAssets(Glob glob);