readAsBytes abstract method

  1. @override
Future<List<int>> readAsBytes(
  1. AssetId id
)

Reads the bytes from id.

  • Throws a PackageNotFoundException if id.package is not found.
  • Throws an AssetNotFoundException if id.path is not found.
  • Throws an InvalidInputException if id is an invalid input. An input is invalid if it is a non-public member of a dependency package; for example by default lib contains public assets but test does not.

Implementation

@override
Future<List<int>> readAsBytes(AssetId id);