reportUnusedAssets abstract method

void reportUnusedAssets(
  1. Iterable<AssetId> ids
)

Indicates that ids were read but their content has no impact on the outputs of this step.

If ids change then build_runner might optimize by not running this step.

Implementation

void reportUnusedAssets(Iterable<AssetId> ids);