resolver property

Resolver get resolver

A Resolver that can parse or resolve any Dart source code visible to this build step.

That means all source files in all transitive deps of the current package, all source files in the current package and all files output by builders that run before the current builder in the current build.

Implementation

Resolver get resolver;