Builder class abstract
A builder in the build_runner build.
Each builder specifies which files it matches as buildExtensions; matching files are called "primary inputs".
During the build build_runner runs the build method of each builder once
per primary input, with a BuildStep created for that input.
- Implementers
Constructors
- Builder()
Properties
-
buildExtensions
→ Map<
String, List< String> > -
Mapping from input file extension to output file extensions.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildStep buildStep) → FutureOr< void> - Generates the outputs for a given BuildStep.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited