digest abstract method
Returns a Digest representing a hash of the contents of id.
This is not intended for use by builders: build_runner already checks
input digests to only run build steps if inputs changed.
Implementation
Future<Digest> digest(AssetId id);